{% extends "!layout.html" %}

{% block rootrellink %}
        <li><img src="{{ pathto('_static/swirl.png', 1) }}" alt=""
                 style="vertical-align: middle; margin-top: -1px"/></li>
        <li><a href="https://www.debian.org/">Debian</a>{{ reldelim1 }}</li>
        <li><span class="language_switcher_placeholder">{{ language or 'en' }}</span>{{ reldelim1 }}</li>
        <li><a href="{{ pathto('index') }}">{{ shorttitle }}</a>{{ reldelim1 }} </li>
{% endblock %}
