/* Debian Cascading stylesheet for Sphinx */

div.related {
    background-color: #C70036;
}

.rst-content h1, .rst-content h2, .rst-content h3, .rst-content h4, .rst-content h5, .rst-content h6 {
    color: #C70036;
}

.wy-nav-top {
    background-color: #C70036;
}

.wy-side-nav-search {
    background-color: #C70036;
}

.rst-content a:link {
    color: #0035C7;
    text-decoration: none;
}
.rst-content a:visited {
    color: #00207A;
    text-decoration: none;
}
.rst-content a:link:hover {
    color: #00207A;
    text-decoration: underline;
}


/* Table in content */

.wy-table-responsive table td, .wy-table-responsive table th {
    white-space: normal;
}

.rst-content table.docutils, .wy-table-bordered-all {
    width: 100%;
}

.wy-table-responsive table.docutils thead tr {
    background-color: #C70036;
    border: 1px solid black;
    color: black;
}

.wy-table-responsive table.docutils thead tr:hover {
    color: #fcfcfc;
}

.wy-table-responsive table.docutils tbody tr:hover {
    background-color:#666666;
    color: #FFFFFF;
}

.rst-content table.docutils:not(.field-list) tbody tr:hover:nth-child(2n-1), .wy-table-backed, .wy-table-odd td, .wy-table-striped tr:nth-child(2n-1) td {
    background-color:#666666;
}

/* Previous and next buttons */

.rst-footer-buttons .btn:hover {
    text-decoration: none !important;
}

/* Version release more readable */

.wy-side-nav-search > div.version {
    color: #FCFCFC;
}

/* Infos blocks */

div.warning {
    border: 1px dashed #EFF500;
    background-color: #eff50030;
}

div.note {
    border: 1px dashed blue;
    background-color: #0000ff30;

}

.warning, .note {
    margin-left: 1em;
    margin-right: 1em;
}

@media (max-width: 5in), (max-device-width: 5in){
    .warning, .note {
        margin-left: 0.5em;
        margin-right: 0.5em;
    }
}

/* Notes */

html.writer-html5 .rst-content aside.citation, html.writer-html5 .rst-content aside.footnote, html.writer-html5 .rst-content div.citation {
    display: block;
}
